@@ -1,11 +1,10 @@
 import inspect
 import json
 import logging
-import os
-import threading
 from collections import defaultdict
 from functools import partial
 
+import gevent
 from kikyo import Kikyo, DataHub
 from kikyo.settings import Settings
 
@@ -26,7 +25,6 @@ class BaseWorker:
 
         log.info('settings: %s', json.dumps(self.settings, ensure_ascii=False, indent=4))
 
-        self._init_env()
         assert self.name is not None
         self.debug = self.settings.get('debug', False)
         self.workers = self.settings.get('workers', 1)
@@ -54,11 +52,6 @@ class BaseWorker:
         if self._sink:
             self._producer = self.kikyo.component(cls=DataHub).create_producer(self._sink)
 
-    def _init_env(self):
-        worker_name = os.environ.get('KIKYOPP_WORKER_NAME')
-        if worker_name:
-            self.name = worker_name
-
     def _init_components(self):
         from kikyo import configure_by_consul
 
@@ -76,12 +69,10 @@ class BaseWorker:
 
         jobs = []
         for i in range(self.workers):
-            t = threading.Thread(target=partial(self.consumer.run, self._source), daemon=True)
-            t.start()
-            jobs.append(t)
-
-        for job in jobs:
-            job.join()
+            jobs.append(
+                gevent.spawn(partial(self.consumer.run, self._source))
+            )
+        gevent.wait(jobs)
 
     def process(self, data: dict):
         try:
